import click
from utils.color import *


@click.group()
def translate():
    '''翻译服务'''
    pass


@translate.command()
@click.argument('tl', metavar='<target>')
@click.argument('text', metavar='<text>')
@click.argument('sl', metavar='[source]', default='auto')
def baidu(sl, tl, text):
    '''\b
    使用百度翻译进行翻译
    将 <text> 由 <source> 翻译为 <target>
    如 <source> 被省略，则自动识别源语言'''
    import requests
    import json
    import random
    import hashlib
    import sys

    appid = '20180325000139814'
    secret = 'UneRTwnSimKz6CzhaVhR'

    salt = random.randint(32768, 65536)
    sign = appid + text + str(salt) + secret
    sign = hashlib.md5(sign.encode()).hexdigest()
    url = 'https://fanyi-api.baidu.com/api/trans/vip/translate?appid=' + appid + '&q=' + text + '&from=' + sl + '&to=' + tl + '&salt=' + str(
        salt) + '&sign=' + sign
    res = None
    try:
        response = requests.post(url)
        res = json.loads(response.content.decode())
    except requests.RequestException as e:
        click.echo(error('无法发送请求，请检查你的网络连接'))
        click.echo(error(str(e)))
        sys.exit(1)

    error_code_map = {
        52001: '请求超时，请检查网络连接或尝试重新执行',
        52002: '系统错误，请尝试重新执行',
        52003: '服务可能已失效，请联系开发人员确认',
        54000: '缺少必要参数',
        54001: '签名错误，请联系开发人员处理',
        54003: '请求频率过高，请稍后再试',
        54004: '服务可能已失效，请联系开发人员确认',
        54005: '请求频率过高，请稍后再试',
        58000: '未授权的访问源，请联系开发人员处理',
        58002: '服务可能已失效，请联系开发人员确认',
        90107: '服务可能已失效，请联系开发人员确认'
    }

    if 'error_code' in res:
        click.echo(error('%s: %s' % (res['error_code'], res['error_msg'])))
        click.echo(error('%s' % error_code_map[res['error_code']]))
    elif 'trans_result' in res:
        result = res['trans_result'][0]
        click.echo(info('原文：%s' % result['src']))
        click.echo(success('译文：%s' % result['dst']))
    else:
        click.echo(error('无法识别返回值'))



import click
from utils.color import *
import requests
from vendor.geoip import getGeoInfo, getCityCode, getLocalIP
from utils.input import select


@click.group()
def weather():
    '''天气查询服务'''
    pass


@weather.command('check', short_help='查询当前位置的天气')
def check():
    '''\b
    查询当前位置的天气
    支持 国家气象局 和 魅族天气 两种天气信息源'''
    click.echo(info('正在获取您的地理位置...'))
    geo_info = getGeoInfo(getLocalIP())
    province = geo_info.subdivisions[0].names['zh-CN']
    city = geo_info.city.names['zh-CN']
    city = str(city).replace('市', '')
    click.echo(info('正在查询城市代码...'))
    code = getCityCode(province, city)
    click.echo(success('当前位置：%s省 %s市 [%s]' % (province, city, code)))
    provider = select('请选择天气信息源：', {'gov': '国家气象局', 'meizu': '魅族天气'})
    if provider == 'meizu':
        checkByMeiZu(code)
    if provider == 'gov':
        checkByGov(code)


def checkByGov(code):
    click.echo(info('正在查询当地天气...'))
    r = requests.get('http://www.weather.com.cn/data/sk/%s.html' % code)
    r.encoding = 'utf-8'

    data = r.json()['weatherinfo']
    click.echo(success('温度：%s 摄氏度' % data['temp']))
    click.echo(success('相对湿度: %s' % data['SD']))
    click.echo(success('风向：%s' % data['WD']))
    click.echo(success('风速：%s' % data['WS']))
    click.echo(success('大气压强：%s' % data['AP']))
    click.echo(info('最后更新于 %s' % data['time']))
    if data['isRadar'] == '1':
        click.echo(info('以上信息由 %s 雷达站收集获得' % data['Radar']))


def checkByMeiZu(code):
    r = requests.get(
        'https://aider.meizu.com/app/weather/listWeather?cityIds=%s' % code)
    data = r.json()

    if data['code'] == '200':
        data = data['value'][0]
        click.pause(info('请按任意键以展示实时天气'))
        click.clear()
        click.echo(info('= 实时天气 ='))
        click.echo(success('天气：%s' % data['realtime']['weather']))
        click.echo(success('温度：%s 摄氏度' % data['realtime']['temp']))
        click.echo(success('相对湿度: %s' % data['realtime']['sD']))
        click.echo(success('风向：%s' % data['realtime']['wD']))
        click.echo(success('风速：%s' % data['realtime']['wS']))
        click.pause(info('请按任意键以展示空气指数'))
        click.clear()
        click.echo(info('= 空气指数 ='))
        click.echo(success('空气质量指数：%s [%s]' % (
            data['pm25']['aqi'], data['pm25']['quality'])))
        click.echo(success('PM2.5含量：%s' % data['pm25']['pm25']))
        click.echo(success('PM1.0含量：%s' % data['pm25']['pm10']))
        click.echo(info('空气质量在 %d 个城市中排名第 %d' %
                        (data['pm25']['citycount'], data['pm25']['cityrank'])))
        click.pause(info('请按任意键以展示生活建议'))
        click.clear()
        click.echo(info('= 生活建议 ='))
        for suggest in data['indexes']:
            click.echo(success('%s：%s' % (suggest['name'], suggest['level'])))
            click.echo(success('建议：%s' % suggest['content']))
        click.echo(info('以上信息由 魅族天气 提供'))



import click
from utils.color import *
from utils.config import config, set_config
import sys
import utils.input as input
import utils.validate as validator
import subprocess
import os


@click.group()
@click.pass_context
def server(ctx):
    '''管理 Minecraft 服务器'''
    ctx.ensure_object(dict)
    ctx.obj['status_map'] = {
        'stopped': '已停止',
        'stopping': '停止中',
        'starting': '启动中',
        'running': '运行中'
    }
    ctx.obj['status'] = 'stopped'
    ctx.obj['process'] = None
    ctx.obj['mcdir'] = '/data/mcserver'


@server.command()
@click.pass_context
def status(ctx, silent=False):
    '''获取服务器状态'''

    ctx.invoke(sync_status, True)

    if not silent:
        status_text = ctx.obj['status_map'].get(ctx.obj['status'])
        click.echo(info('当前服务器状态为 %s' % status_text))

    return ctx.obj['status']


@server.command('change-status', short_help='设定服务器状态')
@click.argument('target', metavar='<status>')
@click.pass_context
def change_status(ctx, target):
    '''\b
    将服务器状态设定为 <status>
    服务器实际状态不会变更，仅作用于内部识别区'''
    if target in ctx.obj['status_map']:
        ctx.obj['status'] = target
        status_text = ctx.obj['status_map'].get(ctx.obj['status'])
        click.echo(success('服务器状态已切换至 %s' % status_text))
        ctx.invoke(status)
    else:
        click.echo(warn('未知的目标状态'))


@server.command('sync-status', short_help='同步服务器状态')
@click.pass_context
def sync_status(ctx, silent=False):
    '''自动同步服务器状态'''

    output = os.popen('screen -ls').read()

    if '.smcserver' in output:
        if not silent:
            click.echo(info('已检测到服务器进程'))
        ctx.obj['status'] = 'running'
    else:
        if not silent:
            click.echo(info('服务器进程不存在'))
        ctx.obj['status'] = 'stopped'


@server.command()
def setup():
    '''配置服务器'''

    if config('server.setup'):
        click.echo(warn('您已经配置过一次服务器了，继续配置将会重置配置'))
        click.confirm(info('是否继续进行配置？'), False, abort=True)

    jar_file = input.ask('服务端（JAR）文件路径', rule='ext|jar')
    set_config('server.jar_file', jar_file)

    max_ram = input.ask('服务端最大运行内存（MB）', 2048, rule='int')
    set_config('server.max_ram', max_ram)


@server.command()
@click.argument('command', metavar='<command>')
@click.pass_context
def exec(ctx, command):
    '''在服务器中执行命令'''
    rstatus = ctx.invoke(status, True)
    if rstatus == 'running':
        os.system('screen -S smcserver -X stuff "{}\015"'.format(command))
    else:
        click.echo(error('服务器进程不存在'))


@server.command()
@click.pass_context
def start(ctx):
    '''启动服务器'''

    if not config('server.setup'):
        click.echo(warn('请先配置服务器管理系统'))
        click.confirm(info('是否现在进行配置？'), True, True)
        ctx.invoke(setup)

    rstatus = ctx.invoke(status, True)
    if rstatus == 'stopped':
        os.chdir(ctx.obj['mcdir'])
        os.system(
            'screen -dmS smcserver java -Xms1G -Xmx2G -jar minecraft_server.1.12.2.jar nogui')
        click.echo(success('服务器已启动'))
    else:
        click.echo(error('服务器进程已存在'))


@server.command()
@click.pass_context
def stop(ctx):
    rstatus = ctx.invoke(status, True)
    if rstatus == 'running':
        ctx.invoke(exec, 'stop')
        click.echo(success('服务器已停止'))
    else:
        click.echo(error('服务器进程不存在'))


@server.command()
@click.pass_context
def web(ctx):
    '''启动 WEB 服务（前台执行）'''
    from http.server import HTTPServer, BaseHTTPRequestHandler
    import json

    host = ('localhost', 8888)

    class Resquest(BaseHTTPRequestHandler):
        def do_GET(self):
            self.send_response(200)
            self.send_header('Content-type', 'application/json')
            self.end_headers()
            data = {'status': ctx.invoke(status, True)}
            self.wfile.write(json.dumps(data).encode())

    server = HTTPServer(host, Resquest)
    print("Starting server, listen at: %s:%s" % host)
    server.serve_forever()



import click
from utils.color import *
import speedtest
import subprocess
import shlex
import utils.string


@click.group()
def network():
    '''网络服务'''
    pass


@network.command()
@click.option('--only-upload', is_flag=True, default=False)
@click.option('--only-download', is_flag=True, default=False)
def test(only_upload, only_download):
    '''测试网络速度'''
    click.echo(info('测速服务由 Speedtest.net 提供'))

    p = subprocess.Popen(shlex.split('spenv/bin/speedtest-cli --bytes'),
                         shell=False, stdout=subprocess.PIPE, stderr=subprocess.STDOUT)
    while p.poll() is None:
        line = p.stdout.readline()
        line = line.strip()
        if line:
            search = [
                '...',
                '(', ')',
                'Retrieving speedtest.net configuration',
                'Testing from ',
                'Retrieving speedtest.net server list',
                'Selecting best server based on ping',
                'Hosted by ',
                'Testing download speed',
                'Download: ',
                'Testing upload speed',
                'Upload: ',
                'Cannot retrieve speedtest configuration',
                'Unable to connect to servers to test latency.'
            ]
            replace = [
                '',
                '（', '）',
                '正在连接测速服务...',
                '待测速服务器为：',
                '正在查询可用测速服务器列表...',
                '正在智能选择延迟最低的测速服务器...',
                '已连接测速服务器：',
                '正在测试下载速度...',
                ';success;下载速度：',
                '正在测试上传速度...',
                ';success;上传速度：',
                ';error;无法连接至测速服务',
                ';error;无法连接到测速服务器'
            ]
            o = utils.string.replace(
                search, replace, line.decode('utf-8'))
            if ';error;' in o:
                o = o.replace(';error;', '')
                click.echo(error(o))
            elif 'ERROR:' in o:
                o = o.replace('ERROR: ', '')
                click.echo(error(o))
            elif ';success;' in o:
                o = o.replace(';success;', '')
                click.echo(success(o))
            else:
                click.echo(info(o))



from setuptools import setup, find_packages

VERSION = '0.1.1'

setup(name='sxysp',
      version=VERSION,
      description='SXYSP Cli Toolbox',
      long_description='SXYSP Cli Toolbox',
      classifiers=[],
      keywords='sxysp',
      author='sunxyw',
      author_email='xy2496419818@gmail.com',
      url='https://github.com/xxx',
      license='MIT',
      packages=find_packages(),
      include_package_data=True,
      zip_safe=True,
      install_requires=[
          'Click',
          'PyYAML',
          'Requests',
          'Speedtest-cli'
      ],
      python_requires='>=2.7, <4',
      entry_points={
          'console_scripts': [
              'sxysp = index:cli'
          ]
      })
